#!/usr/bin/env python3
import os
from flask import Flask
from werkzeug.middleware.proxy_fix import ProxyFix

# import stuff
from utils import register_all_error_handlers, storage

# import views
from views import ObjectView

# create flask app
app = Flask(__name__)
app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1)

# init stuff
storage.init_app(app)

# important stuff
app.secret_key = os.environ.get('SECRET_KEY', os.urandom(12))

app.config['MINIO_ENDPOINT'] = os.environ['MINIO_ENDPOINT']
app.config['MINIO_ACCESS_KEY'] = os.environ['MINIO_ACCESS_KEY']
app.config['MINIO_SECRET_KEY'] = os.environ['MINIO_SECRET_KEY']

# register error handlers
register_all_error_handlers(app)

# register views
for view in [ObjectView]:
    view.register(app, trailing_slash=False)

# start debugging if needed
if __name__ == "__main__":
    app.run(debug=True)
